@@ -71,7 +71,7 @@ def qctrl_pulse_to_samples(
 
     segments = np.repeat(
         [segment["value"] for segment in qctrl_pulse],
-        [np.rint(segment["duration"]) / 1e-9 for segment in qctrl_pulse],
+        [np.rint(segment["duration"] / 1e-9) for segment in qctrl_pulse],
     )
     segments = np.pad(segments, (0, 4 - len(segments) % 4))
 
@@ -156,7 +156,7 @@ class _Qubit:
         self.mixer_name = mixer_name
         self.name = name
 
-    def _add_operation(self, operation_name, pulse_name):
+    def add_operation(self, operation_name, pulse_name):
         self.config["operations"][operation_name] = pulse_name
 
 
@@ -322,7 +322,7 @@ class _Resonator:
         ]
         self.name = name
 
-    def _add_operation(self, operation_name, pulse_name):
+    def add_operation(self, operation_name, pulse_name):
         self.config["operations"][operation_name] = pulse_name
 
 
@@ -442,7 +442,7 @@ class QmConfig:
                 mixer_name=mixer_name,
             )
             for pulse_name in drive_pulses:
-                element_qubit._add_operation(pulse_name, pulse_name)
+                element_qubit.add_operation(pulse_name, pulse_name)
             self.qubits.append(element_qubit)
 
             config["elements"][element_name] = element_qubit.config
@@ -464,7 +464,7 @@ class QmConfig:
                 mixer_name=mixer_name,
             )
             for pulse_name in measurement_pulses:
-                element_resonator._add_operation(pulse_name, pulse_name)
+                element_resonator.add_operation(pulse_name, pulse_name)
             self.resonators.append(element_resonator)
 
             config["elements"][element_name] = element_resonator.config
@@ -502,7 +502,7 @@ class QmConfig:
 
         if not operation_name:
             operation_name = pulse_name
-        qb._add_operation(operation_name, pulse_name)
+        qb.add_operation(operation_name, pulse_name)
         self.config["elements"][qb.name] = qb.config
 
     def assign_meas_pulse(self, resonator_index, pulse, operation_name=None):
@@ -534,7 +534,7 @@ class QmConfig:
         if not operation_name:
             operation_name = pulse_name
 
-        resonator._add_operation(operation_name, pulse_name)
+        resonator.add_operation(operation_name, pulse_name)
         self.config["elements"][resonator.name] = resonator.config
         for integ_name, weights in pulse.integ.items():
             self.config["integration_weights"][integ_name] = weights
